@@ -2,14 +2,13 @@
 
 from datetime import datetime
 
-
-project = "meteofrance-api"
-author = "HACF"
+project = "Météo-France API"
+author = "HACF (created by @oncleben31 & @Quentame, maintained by @Quentame)"
 copyright = f"{datetime.now().year}, {author}"
 extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.napoleon",
-    "sphinx_rtd_theme",
+    "myst_parser",
 ]
 autodoc_typehints = "description"
-html_theme = "sphinx_rtd_theme"
+html_theme = "furo"
